@@ -25,9 +25,10 @@
 */
 
 #include <iomanip>
-#include "catch.hpp"
+#include "catch_amalgamated.hpp"
 #include "color-conversion/colorconversion.h"
 #include "pixelimage.h"
+#include <cmath>
 
 // Enable for more verbose test output.
 constexpr bool kEnableDebugOutput = false;
@@ -70,13 +71,13 @@ std::string PrintChannel(const HeifPixelImage& image, heif_channel channel) {
   heif_chroma chroma = image.get_chroma_format();
   int num_interleaved = num_interleaved_pixels_per_plane(chroma);
   bool is_interleaved = num_interleaved > 1;
-  int max_cols = is_interleaved ? 3 : 10;
-  int max_rows = 10;
-  int width = std::min(image.get_width(channel), max_cols);
-  int height = std::min(image.get_height(channel), max_rows);
-  int stride;
+  uint32_t max_cols = is_interleaved ? 3 : 10;
+  uint32_t max_rows = 10;
+  uint32_t width = std::min(image.get_width(channel), max_cols);
+  uint32_t height = std::min(image.get_height(channel), max_rows);
+  uint32_t stride;
   const T* p = (T*)image.get_plane(channel, &stride);
-  stride /= sizeof(T);
+  stride /= (int)sizeof(T);
   int bpp = image.get_bits_per_pixel(channel);
   int digits = (int)std::ceil(std::log10(1 << bpp)) + 1;
 
@@ -85,13 +86,13 @@ std::string PrintChannel(const HeifPixelImage& image, heif_channel channel) {
      << " bpp=" << bpp << "\n";
   os << std::string(digits, ' ');
   int header_width = digits * num_interleaved - 1 + (is_interleaved ? 3 : 0);
-  for (int x = 0; x < width; ++x) {
+  for (uint32_t x = 0; x < width; ++x) {
     os << "|" << std::left << std::setw(header_width) << std::to_string(x);
   }
   os << "\n";
-  for (int y = 0; y < height; ++y) {
+  for (uint32_t y = 0; y < height; ++y) {
     os << std::left << std::setw(digits) << std::to_string(y) << "|";
-    for (int x = 0; x < width; ++x) {
+    for (uint32_t x = 0; x < width; ++x) {
       if (is_interleaved) os << "(";
       for (int k = 0; k < num_interleaved; ++k) {
         int v = SwapBytesIfNeeded(p[y * stride + x * num_interleaved + k], chroma);
@@ -118,23 +119,27 @@ std::string PrintChannel(const HeifPixelImage& image, heif_channel channel) {
 template <typename T>
 double GetPsnr(const HeifPixelImage& original, const HeifPixelImage& compressed,
                heif_channel channel, bool expect_alpha_max) {
-  int w = original.get_width(channel);
-  int h = original.get_height(channel);
+  uint32_t w = original.get_width(channel);
+  uint32_t h = original.get_height(channel);
   heif_chroma chroma = original.get_chroma_format();
 
-  int orig_stride;
-  int compressed_stride;
+  if (w == 0 || h == 0) {
+    return 0;
+  }
+
+  uint32_t orig_stride;
+  uint32_t compressed_stride;
   const T* orig_p = (T*)original.get_plane(channel, &orig_stride);
   const T* compressed_p = (T*)compressed.get_plane(channel, &compressed_stride);
-  orig_stride /= sizeof(T);
-  compressed_stride /= sizeof(T);
+  orig_stride /= (int)sizeof(T);
+  compressed_stride /= (int)sizeof(T);
   double mse = 0.0;
 
   int num_interleaved = num_interleaved_pixels_per_plane(chroma);
   int alpha_max = (1 << original.get_bits_per_pixel(channel)) - 1;
   CAPTURE(expect_alpha_max);
-  for (int y = 0; y < h; y++) {
-    for (int x = 0; x < w * num_interleaved; x++) {
+  for (uint32_t y = 0; y < h; y++) {
+    for (uint32_t x = 0; x < w * num_interleaved; x++) {
       int orig_v = SwapBytesIfNeeded(orig_p[y * orig_stride + x], chroma);
       if (expect_alpha_max && (channel == heif_channel_Alpha ||
                                ((num_interleaved == 4) && x % 4 == 3))) {
@@ -283,8 +288,8 @@ void TestConversion(const std::string& test_name, const ColorState& input_state,
   int height = 8;
   REQUIRE(MakeTestImage(input_state, width, height, in_image.get()));
 
-  std::shared_ptr<HeifPixelImage> out_image =
-      pipeline.convert_image(in_image);
+  std::shared_ptr<HeifPixelImage> out_image;
+  out_image = pipeline.convert_image(in_image);
 
   REQUIRE(out_image != nullptr);
   CHECK(out_image->get_colorspace() == target_state.colorspace);
@@ -292,7 +297,7 @@ void TestConversion(const std::string& test_name, const ColorState& input_state,
   CHECK(out_image->has_alpha() == target_state.has_alpha);
   for (const Plane& plane : GetPlanes(target_state, width, height)) {
     INFO("Channel: " << plane.channel);
-    int stride;
+    uint32_t stride;
     CHECK(out_image->get_plane(plane.channel, &stride) != nullptr);
     CHECK(out_image->get_bits_per_pixel(plane.channel) ==
           target_state.bits_per_pixel);
@@ -602,7 +607,7 @@ static void fill_plane(std::shared_ptr<HeifPixelImage>& img, heif_channel channe
 {
   img->add_plane(channel, w, h, 8);
 
-  int stride;
+  uint32_t stride;
   uint8_t* p = img->get_plane(channel, &stride);
 
   for (int y = 0; y < h; y++) {
@@ -616,15 +621,15 @@ static void fill_plane(std::shared_ptr<HeifPixelImage>& img, heif_channel channe
 static void assert_plane(std::shared_ptr<HeifPixelImage>& img, heif_channel channel, const std::vector<uint8_t>& pixels)
 {
   INFO("channel: " << channel);
-  int w = img->get_width(channel);
-  int h = img->get_height(channel);
+  uint32_t w = img->get_width(channel);
+  uint32_t h = img->get_height(channel);
 
-  int stride;
+  uint32_t stride;
   uint8_t* p = img->get_plane(channel, &stride);
 
-  for (int y = 0; y < h; y++) {
+  for (uint32_t y = 0; y < h; y++) {
     INFO("row: " << y);
-    for (int x = 0; x < w; x++) {
+    for (uint32_t x = 0; x < w; x++) {
       INFO("column: " << x);
       REQUIRE((int)p[y * stride + x] == (int)pixels[y * w + x]);
     }
@@ -674,8 +679,8 @@ TEST_CASE("RGB 5-6-5 to RGB")
   heif_color_conversion_options options = {};
 
   std::shared_ptr<HeifPixelImage> img = std::make_shared<HeifPixelImage>();
-  const int width = 3;
-  const int height = 2;
+  const uint32_t width = 3;
+  const uint32_t height = 2;
   img->create(width, height, heif_colorspace_RGB, heif_chroma_444);
   img->add_plane(heif_channel_R, width, height, 5);
   REQUIRE(img->get_bits_per_pixel(heif_channel_R) == 5);
@@ -686,12 +691,12 @@ TEST_CASE("RGB 5-6-5 to RGB")
 
   uint8_t v = 1;
   for (heif_channel plane: {heif_channel_R, heif_channel_G, heif_channel_B}) {
-    int dst_stride = 0;
+    uint32_t dst_stride = 0;
     uint8_t *dst = img->get_plane(plane, &dst_stride);
-    for (int y = 0; y < height; y++) {
-      for (int x = 0; x < width; x++) {
+    for (uint32_t y = 0; y < height; y++) {
+      for (uint32_t x = 0; x < width; x++) {
         dst[y * dst_stride + x] = v;
-        v += 1;
+        v++;
       }
     }
   }
